@@ -2,7 +2,8 @@ from django.views.generic import DetailView
 from ipware import get_client_ip
 from user_agents import parse
 
-from .helpers.ua import ua_to_dict, get_platform_bools
+from .helpers import get_querystring_as_dict
+from .helpers.ua import get_platform_bools, ua_to_dict
 from .models import App, Visit
 from .settings import api_settings
 
@@ -34,11 +35,11 @@ class AppDownloadView(DetailView):
                 ip_address=ip_address,
                 ua_data=ua_data,
                 ip_data=ip_data,
+                query_data=get_querystring_as_dict(self.request),
                 deep_link=self.object,
             )
 
         ctx = super().get_context_data(**kwargs)
         ctx["user_agent"] = user_agent
         ctx.update(get_platform_bools(user_agent))
-        print(ctx)
         return ctx
